TxTransaction

Struct TxTransaction 

pub struct TxTransaction<'ch, 'data> { /* private fields */ }
An in-progress transaction for a single shot TX transaction.

If the data size exceeds the size of the internal buffer, .poll() or .wait() needs to be called before the entire buffer has been sent to avoid underruns.

Implementations

Source

impl<'ch> TxTransaction<'ch, '_>

pub fn poll(&mut self) -> bool

Check transmission status and write new data to the hardware if necessary.

Returns whether transmission has ended (whether successfully or with an error). In that case, a subsequent call to wait() returns immediately.

pub fn wait( self, ) -> Result<Channel<'ch, Blocking, Tx>, (Error, Channel<'ch, Blocking, Tx>)>

Wait for the transaction to complete